@@ -3,8 +3,8 @@ from getpass import getpass
 from typing import Optional
 
 import grpc
-from numerous_api_client.python_protos.spm_pb2 import LoginCredentials, RefreshRequest, Token, TokenRequest
-from numerous_api_client.python_protos.spm_pb2_grpc import TokenManagerStub
+from spm_pb2 import LoginCredentials, RefreshRequest, Token, TokenRequest
+from spm_pb2_grpc import TokenManagerStub
 
 from .repository import NumerousRepository, ProjectScenario
 from .utils import bold, get_token_manager, yellow
@@ -24,7 +24,7 @@ class TokenAuth(grpc.AuthMetadataPlugin):
 
 
 def get_refresh_token(token_manager: TokenManagerStub, repo: NumerousRepository, email: str, password: str,
-                      scenario: Optional[ProjectScenario] = None) -> Optional[str]:
+                      scenario: Optional[ProjectScenario] = None, admin: Optional[bool] = False) -> Optional[str]:
 
     if scenario is None:
         if repo.scenario is None:
@@ -40,13 +40,13 @@ def get_refresh_token(token_manager: TokenManagerStub, repo: NumerousRepository,
         project_id=project_id,
         scenario_id=scenario_id,
         execution_id=f"numerous_cli-{uuid.uuid4()}",
-        admin=False,
+        admin=bool(admin),
         job_id=repo.remote.job_id if repo.remote is not None else None,  # TODO: maybe fail early if remote not defined
         user_id=None,
         organization_id=repo.organization,
         agent=None,
         purpose=None,
-        access_level=3
+        access_level=5 if admin else 3
     )
 
     credentials = LoginCredentials(
@@ -70,7 +70,7 @@ def get_access_token(token_manager: TokenManagerStub, repo: NumerousRepository,
     return str(token_manager.GetAccessToken(refresh_request).val)
 
 
-def login(repo: NumerousRepository, scenario: Optional[ProjectScenario] = None):
+def login(repo: NumerousRepository, scenario: Optional[ProjectScenario] = None, admin: Optional[bool] = False):
     if repo.remote is None:
         raise AuthenticationError()
 
@@ -85,13 +85,13 @@ def login(repo: NumerousRepository, scenario: Optional[ProjectScenario] = None):
         except Exception:  # nosec
             pass
 
-    print(yellow(f"Login to {bold(scenario)} at {bold(repo.remote)}"))
+    print(yellow(f"Login to {bold(scenario)} at {bold(repo.remote)} {'requesting admin level' if admin else ''}"))
     email = input("Email: ")  # nosec
     password = getpass("Password: ")
 
     with get_token_manager(repo.remote.api_url) as token_manager:
         try:
-            token = get_refresh_token(token_manager, repo, email, password, scenario)
+            token = get_refresh_token(token_manager, repo, email, password, scenario, admin=admin)
             if token is None:
                 raise AuthenticationError()
             repo.token = token
