@@ -6,7 +6,7 @@ from ..repository import NumerousRepository
 from ..utils import bold, green, red
 
 
-def command_login(log: Logger, path: Path):
+def command_login(log: Logger, path: Path, admin: bool):
     path = path or Path.cwd()
 
     try:
@@ -29,7 +29,7 @@ def command_login(log: Logger, path: Path):
 
     repo.token = None
     try:
-        login(repo)
+        login(repo, admin=admin)
         print(green("Login succeeded."))
     except AuthenticationError:
         print(red("Login failed."))
