@@ -82,33 +82,3 @@ class NumerousRepository:
             self.snapshot = config["snapshot"]
             self.token = config["token"]
             return self
-
-    def get_client(self, clear_data: Optional[bool] = None,
-                   no_log: bool = False, instance_id: Optional[str] = None):
-        """
-        Returns a `NumerousClient` instance configured to connect to the API
-        at the remote of this repository. All arguments are passed on to the
-        client constructor.
-        """
-        if self.remote is None:
-            raise RuntimeError("Repository remote is undefined")
-        if self.scenario is None:
-            raise RuntimeError("Repository scenario is undefined")
-
-        from numerous_api_client.client import NumerousClient
-        return NumerousClient(url=self.remote.api_url,
-                              project=self.scenario.project_id,
-                              scenario=self.scenario.id,
-                              job_id=self.remote.job_id,
-                              refresh_token=self.token, clear_data=clear_data,
-                              no_log=no_log, instance_id=instance_id)
-
-    def get_admin_client(self):
-        """
-        Returns a `NumerousAdminClient` instance configured to connect to the
-        API at the remote of this repository.
-        """
-        from numerous_api_client.client import NumerousAdminClient
-        admin_client = NumerousAdminClient(url=self.remote.api_url,
-                                           refresh_token=self.token)
-        return admin_client
