@@ -44,16 +44,18 @@ def parse_arguments():
     parser_log.add_argument("path", help="The path to the repository", nargs="?")
 
     parser_push = command_parsers.add_parser("push", help="Push to the remote.")
-    parser_push.add_argument("path", help="The path to the repository", nargs="?")
+    parser_push.add_argument("path", help="The path to the repository.", nargs="?")
     parser_push.add_argument("-c", "--comment", help="The comment for the push commit.", required=True)
 
     parser_build = command_parsers.add_parser("build", help="Build the code the code.")
     parser_build.add_argument("path", help="The path to the repository.", nargs="?")
     parser_build.add_argument("-c", "--commit", help="The commit to build.")
     parser_build.add_argument("-j", "--job", help="The job id of the job to associate the image with.")
+    parser_build.add_argument("-t", "--tags", help="Extra tags separated by commas.")
 
     parser_login = command_parsers.add_parser("login", help="Login to the repository remote.")
-    parser_login.add_argument("path", help="The path to the repository", nargs="?")
+    parser_login.add_argument("path", help="The path to the repository.", nargs="?")
+    parser_login.add_argument("--admin", help="Request the admin level.", action='store_true')
 
     command_parsers.add_parser("version", help="Get the current version number of this tool.")
 
@@ -89,13 +91,14 @@ def run_command(ns: Namespace):
     elif ns.cmd == "checkout":
         commands.command_checkout(log, path_or_none(ns.path), ns.scenario, ns.commit)
     elif ns.cmd == "build":
-        commands.command_build(log, path_or_none(ns.path), ns.commit, job=ns.job)
+        tags = [tag.strip() for tag in ns.tags.split(',')] if ns.tags else None
+        commands.command_build(log, path_or_none(ns.path), ns.commit, job=ns.job, tags=tags)
     elif ns.cmd == "config":
         commands.command_config(log, path_or_none(ns.path), ns)
     elif ns.cmd == "version":
         commands.command_version()
     elif ns.cmd == "login":
-        commands.command_login(log, path_or_none(ns.path))
+        commands.command_login(log, path_or_none(ns.path), ns.admin)
     else:
         print(red(f"Invalid {ns.cmd} command given."))
 
