@@ -11,7 +11,7 @@ from uuid import uuid4
 import grpc
 from colorama import Fore, Style, init as init_colorama
 from dirtools import Dir
-from numerous_api_client.python_protos.spm_pb2_grpc import BuildManagerStub, SPMStub, TokenManagerStub
+from spm_pb2_grpc import BuildManagerStub, SPMStub, TokenManagerStub
 
 log = logging.getLogger('numerous.build-cli')
 
